@@ -20,6 +20,8 @@ from botocore.client import BaseClient, ClientMeta
 
 from .literals import (
     ApplicationComponentCriteriaType,
+    ApplicationModeType,
+    AppTypeType,
     DataSourceTypeType,
     InclusionStatusType,
     OutputFormatType,
@@ -35,11 +37,13 @@ from .paginator import (
 )
 from .type_defs import (
     ApplicationPreferencesTypeDef,
+    AssessmentTargetTypeDef,
     DatabasePreferencesTypeDef,
     GetApplicationComponentDetailsResponseTypeDef,
     GetApplicationComponentStrategiesResponseTypeDef,
     GetAssessmentResponseTypeDef,
     GetImportFileTaskResponseTypeDef,
+    GetLatestAssessmentIdResponseTypeDef,
     GetPortfolioPreferencesResponseTypeDef,
     GetPortfolioSummaryResponseTypeDef,
     GetRecommendationReportDetailsResponseTypeDef,
@@ -79,6 +83,7 @@ class Exceptions:
     AccessDeniedException: Type[BotocoreClientError]
     ClientError: Type[BotocoreClientError]
     ConflictException: Type[BotocoreClientError]
+    DependencyException: Type[BotocoreClientError]
     InternalServerException: Type[BotocoreClientError]
     ResourceNotFoundException: Type[BotocoreClientError]
     ServiceLinkedRoleLockClientException: Type[BotocoreClientError]
@@ -171,6 +176,14 @@ class MigrationHubStrategyRecommendationsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_migrationhubstrategy/client/#get_import_file_task)
         """
 
+    def get_latest_assessment_id(self) -> GetLatestAssessmentIdResponseTypeDef:
+        """
+        Retrieve the latest ID of a specific assessment task.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/migrationhubstrategy.html#MigrationHubStrategyRecommendations.Client.get_latest_assessment_id)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_migrationhubstrategy/client/#get_latest_assessment_id)
+        """
+
     def get_portfolio_preferences(self) -> GetPortfolioPreferencesResponseTypeDef:
         """
         Retrieves your migration and modernization preferences.
@@ -273,6 +286,7 @@ class MigrationHubStrategyRecommendationsClient(BaseClient):
     def put_portfolio_preferences(
         self,
         *,
+        applicationMode: ApplicationModeType = ...,
         applicationPreferences: ApplicationPreferencesTypeDef = ...,
         databasePreferences: DatabasePreferencesTypeDef = ...,
         prioritizeBusinessGoals: PrioritizeBusinessGoalsTypeDef = ...
@@ -285,7 +299,11 @@ class MigrationHubStrategyRecommendationsClient(BaseClient):
         """
 
     def start_assessment(
-        self, *, s3bucketForAnalysisData: str = ..., s3bucketForReportData: str = ...
+        self,
+        *,
+        assessmentTargets: Sequence[AssessmentTargetTypeDef] = ...,
+        s3bucketForAnalysisData: str = ...,
+        s3bucketForReportData: str = ...
     ) -> StartAssessmentResponseTypeDef:
         """
         Starts the assessment of an on-premises environment.
@@ -333,6 +351,8 @@ class MigrationHubStrategyRecommendationsClient(BaseClient):
         self,
         *,
         applicationComponentId: str,
+        appType: AppTypeType = ...,
+        configureOnly: bool = ...,
         inclusionStatus: InclusionStatusType = ...,
         secretsManagerKey: str = ...,
         sourceCodeList: Sequence[SourceCodeTypeDef] = ...,
