@@ -22,10 +22,14 @@ else:
 __all__ = (
     "AntipatternReportStatusType",
     "AppTypeType",
+    "AppUnitErrorCategoryType",
     "ApplicationComponentCriteriaType",
+    "ApplicationModeType",
     "AssessmentStatusType",
+    "AuthTypeType",
     "AwsManagedTargetDestinationType",
     "CollectorHealthType",
+    "ConditionType",
     "DataSourceTypeType",
     "DatabaseManagementPreferenceType",
     "GetServerDetailsPaginatorName",
@@ -41,11 +45,14 @@ __all__ = (
     "NoPreferenceTargetDestinationType",
     "OSTypeType",
     "OutputFormatType",
+    "PipelineTypeType",
     "RecommendationReportStatusType",
     "ResourceSubTypeType",
     "RunTimeAssessmentStatusType",
+    "RuntimeAnalysisStatusType",
     "SelfManageTargetDestinationType",
     "ServerCriteriaType",
+    "ServerErrorCategoryType",
     "ServerOsTypeType",
     "SeverityType",
     "SortOrderType",
@@ -56,6 +63,7 @@ __all__ = (
     "TargetDestinationType",
     "TransformationToolNameType",
     "VersionControlType",
+    "VersionControlTypeType",
     "MigrationHubStrategyRecommendationsServiceName",
     "ServiceName",
     "ResourceServiceName",
@@ -65,17 +73,53 @@ __all__ = (
 
 
 AntipatternReportStatusType = Literal["FAILED", "IN_PROGRESS", "SUCCESS"]
-AppTypeType = Literal["DotNetFramework", "IIS", "Java", "Oracle", "Other", "SQLServer"]
-ApplicationComponentCriteriaType = Literal[
-    "APP_NAME", "APP_TYPE", "DESTINATION", "NOT_DEFINED", "SERVER_ID", "STRATEGY"
+AppTypeType = Literal[
+    "Cassandra",
+    "DB2",
+    "DotNetFramework",
+    "Dotnet",
+    "DotnetCore",
+    "IBM WebSphere",
+    "IIS",
+    "JBoss",
+    "Java",
+    "Maria DB",
+    "Mongo DB",
+    "MySQL",
+    "Oracle",
+    "Oracle WebLogic",
+    "Other",
+    "PostgreSQLServer",
+    "SQLServer",
+    "Spring",
+    "Sybase",
+    "Tomcat",
+    "Unknown",
+    "Visual Basic",
 ]
+AppUnitErrorCategoryType = Literal[
+    "CONNECTIVITY_ERROR", "CREDENTIAL_ERROR", "OTHER_ERROR", "PERMISSION_ERROR", "UNSUPPORTED_ERROR"
+]
+ApplicationComponentCriteriaType = Literal[
+    "ANALYSIS_STATUS",
+    "APP_NAME",
+    "APP_TYPE",
+    "DESTINATION",
+    "ERROR_CATEGORY",
+    "NOT_DEFINED",
+    "SERVER_ID",
+    "STRATEGY",
+]
+ApplicationModeType = Literal["ALL", "KNOWN", "UNKNOWN"]
 AssessmentStatusType = Literal["COMPLETE", "FAILED", "IN_PROGRESS", "STOPPED"]
+AuthTypeType = Literal["CERT", "NTLM", "SSH"]
 AwsManagedTargetDestinationType = Literal["AWS Elastic BeanStalk", "AWS Fargate", "None specified"]
 CollectorHealthType = Literal["COLLECTOR_HEALTHY", "COLLECTOR_UNHEALTHY"]
-DataSourceTypeType = Literal["ApplicationDiscoveryService", "MPA"]
+ConditionType = Literal["CONTAINS", "EQUALS", "NOT_CONTAINS", "NOT_EQUALS"]
+DataSourceTypeType = Literal["ApplicationDiscoveryService", "Import", "MPA"]
 DatabaseManagementPreferenceType = Literal["AWS-managed", "No preference", "Self-manage"]
 GetServerDetailsPaginatorName = Literal["get_server_details"]
-GroupNameType = Literal["ExternalId"]
+GroupNameType = Literal["ExternalId", "ExternalSourceType"]
 HeterogeneousTargetDatabaseEngineType = Literal[
     "AWS PostgreSQL",
     "Amazon Aurora",
@@ -114,6 +158,7 @@ NoPreferenceTargetDestinationType = Literal[
 ]
 OSTypeType = Literal["LINUX", "WINDOWS"]
 OutputFormatType = Literal["Excel", "Json"]
+PipelineTypeType = Literal["AZURE_DEVOPS"]
 RecommendationReportStatusType = Literal["FAILED", "IN_PROGRESS", "SUCCESS"]
 ResourceSubTypeType = Literal["Database", "DatabaseProcess", "Process"]
 RunTimeAssessmentStatusType = Literal[
@@ -125,22 +170,46 @@ RunTimeAssessmentStatusType = Literal[
     "dataCollectionTaskSuccess",
     "dataCollectionTaskToBeScheduled",
 ]
+RuntimeAnalysisStatusType = Literal[
+    "ANALYSIS_FAILED", "ANALYSIS_STARTED", "ANALYSIS_SUCCESS", "ANALYSIS_TO_BE_SCHEDULED"
+]
 SelfManageTargetDestinationType = Literal[
     "Amazon Elastic Cloud Compute (EC2)",
     "Amazon Elastic Container Service (ECS)",
     "Amazon Elastic Kubernetes Service (EKS)",
     "None specified",
 ]
-ServerCriteriaType = Literal["DESTINATION", "NOT_DEFINED", "OS_NAME", "SERVER_ID", "STRATEGY"]
+ServerCriteriaType = Literal[
+    "ANALYSIS_STATUS",
+    "DESTINATION",
+    "ERROR_CATEGORY",
+    "NOT_DEFINED",
+    "OS_NAME",
+    "SERVER_ID",
+    "STRATEGY",
+]
+ServerErrorCategoryType = Literal[
+    "ARCHITECTURE_ERROR",
+    "CONNECTIVITY_ERROR",
+    "CREDENTIAL_ERROR",
+    "OTHER_ERROR",
+    "PERMISSION_ERROR",
+]
 ServerOsTypeType = Literal[
     "AmazonLinux", "EndOfSupportWindowsServer", "Other", "Redhat", "WindowsServer"
 ]
 SeverityType = Literal["HIGH", "LOW", "MEDIUM"]
 SortOrderType = Literal["ASC", "DESC"]
 SrcCodeOrDbAnalysisStatusType = Literal[
-    "ANALYSIS_FAILED", "ANALYSIS_STARTED", "ANALYSIS_SUCCESS", "ANALYSIS_TO_BE_SCHEDULED"
+    "ANALYSIS_FAILED",
+    "ANALYSIS_PARTIAL_SUCCESS",
+    "ANALYSIS_STARTED",
+    "ANALYSIS_SUCCESS",
+    "ANALYSIS_TO_BE_SCHEDULED",
+    "CONFIGURED",
+    "UNCONFIGURED",
 ]
-StrategyRecommendationType = Literal["notRecommended", "recommended", "viableOption"]
+StrategyRecommendationType = Literal["notRecommended", "potential", "recommended", "viableOption"]
 StrategyType = Literal[
     "Refactor", "Rehost", "Relocate", "Replatform", "Repurchase", "Retain", "Retirement"
 ]
@@ -169,6 +238,7 @@ TargetDestinationType = Literal[
     "Amazon Relational Database Service on PostgreSQL",
     "Aurora MySQL",
     "Aurora PostgreSQL",
+    "Babelfish for Aurora PostgreSQL",
     "None specified",
 ]
 TransformationToolNameType = Literal[
@@ -183,7 +253,8 @@ TransformationToolNameType = Literal[
     "Strategy Recommendation Support",
     "Windows Web Application Migration Assistant",
 ]
-VersionControlType = Literal["GITHUB", "GITHUB_ENTERPRISE"]
+VersionControlType = Literal["AZURE_DEVOPS_GIT", "GITHUB", "GITHUB_ENTERPRISE"]
+VersionControlTypeType = Literal["AZURE_DEVOPS_GIT", "GITHUB", "GITHUB_ENTERPRISE"]
 MigrationHubStrategyRecommendationsServiceName = Literal["migrationhubstrategy"]
 ServiceName = Literal[
     "accessanalyzer",
@@ -209,6 +280,7 @@ ServiceName = Literal[
     "apprunner",
     "appstream",
     "appsync",
+    "arc-zonal-shift",
     "athena",
     "auditmanager",
     "autoscaling",
@@ -226,6 +298,8 @@ ServiceName = Literal[
     "chime-sdk-media-pipelines",
     "chime-sdk-meetings",
     "chime-sdk-messaging",
+    "chime-sdk-voice",
+    "cleanrooms",
     "cloud9",
     "cloudcontrol",
     "clouddirectory",
@@ -236,9 +310,11 @@ ServiceName = Literal[
     "cloudsearch",
     "cloudsearchdomain",
     "cloudtrail",
+    "cloudtrail-data",
     "cloudwatch",
     "codeartifact",
     "codebuild",
+    "codecatalyst",
     "codecommit",
     "codedeploy",
     "codeguru-reviewer",
@@ -275,6 +351,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "docdb-elastic",
     "drs",
     "ds",
     "dynamodb",
@@ -327,9 +404,11 @@ ServiceName = Literal[
     "importexport",
     "inspector",
     "inspector2",
+    "internetmonitor",
     "iot",
     "iot-data",
     "iot-jobs-data",
+    "iot-roborunner",
     "iot1click-devices",
     "iot1click-projects",
     "iotanalytics",
@@ -348,11 +427,13 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "kendra-ranking",
     "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
     "kinesis-video-signaling",
+    "kinesis-video-webrtc-storage",
     "kinesisanalytics",
     "kinesisanalyticsv2",
     "kinesisvideo",
@@ -364,6 +445,7 @@ ServiceName = Literal[
     "lexv2-models",
     "lexv2-runtime",
     "license-manager",
+    "license-manager-linux-subscriptions",
     "license-manager-user-subscriptions",
     "lightsail",
     "location",
@@ -403,7 +485,10 @@ ServiceName = Literal[
     "network-firewall",
     "networkmanager",
     "nimble",
+    "oam",
+    "omics",
     "opensearch",
+    "opensearchserverless",
     "opsworks",
     "opsworkscm",
     "organizations",
@@ -417,6 +502,7 @@ ServiceName = Literal[
     "pinpoint-email",
     "pinpoint-sms-voice",
     "pinpoint-sms-voice-v2",
+    "pipes",
     "polly",
     "pricing",
     "privatenetworks",
@@ -433,6 +519,7 @@ ServiceName = Literal[
     "redshift-serverless",
     "rekognition",
     "resiliencehub",
+    "resource-explorer-2",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -451,12 +538,16 @@ ServiceName = Literal[
     "sagemaker-a2i-runtime",
     "sagemaker-edge",
     "sagemaker-featurestore-runtime",
+    "sagemaker-geospatial",
+    "sagemaker-metrics",
     "sagemaker-runtime",
     "savingsplans",
+    "scheduler",
     "schemas",
     "sdb",
     "secretsmanager",
     "securityhub",
+    "securitylake",
     "serverlessrepo",
     "service-quotas",
     "servicecatalog",
@@ -466,6 +557,7 @@ ServiceName = Literal[
     "sesv2",
     "shield",
     "signer",
+    "simspaceweaver",
     "sms",
     "sms-voice",
     "snow-device-management",
@@ -475,6 +567,7 @@ ServiceName = Literal[
     "ssm",
     "ssm-contacts",
     "ssm-incidents",
+    "ssm-sap",
     "sso",
     "sso-admin",
     "sso-oidc",
@@ -488,6 +581,7 @@ ServiceName = Literal[
     "textract",
     "timestream-query",
     "timestream-write",
+    "tnb",
     "transcribe",
     "transfer",
     "translate",
