@@ -18,12 +18,17 @@ from typing import Dict, List, Sequence
 from .literals import (
     AntipatternReportStatusType,
     ApplicationComponentCriteriaType,
+    ApplicationModeType,
     AppTypeType,
+    AppUnitErrorCategoryType,
     AssessmentStatusType,
+    AuthTypeType,
     AwsManagedTargetDestinationType,
     CollectorHealthType,
+    ConditionType,
     DatabaseManagementPreferenceType,
     DataSourceTypeType,
+    GroupNameType,
     HeterogeneousTargetDatabaseEngineType,
     ImportFileTaskStatusType,
     InclusionStatusType,
@@ -32,9 +37,11 @@ from .literals import (
     OutputFormatType,
     RecommendationReportStatusType,
     ResourceSubTypeType,
+    RuntimeAnalysisStatusType,
     RunTimeAssessmentStatusType,
     SelfManageTargetDestinationType,
     ServerCriteriaType,
+    ServerErrorCategoryType,
     ServerOsTypeType,
     SeverityType,
     SortOrderType,
@@ -45,6 +52,7 @@ from .literals import (
     TargetDestinationType,
     TransformationToolNameType,
     VersionControlType,
+    VersionControlTypeType,
 )
 
 if sys.version_info >= (3, 9):
@@ -59,16 +67,24 @@ else:
 
 __all__ = (
     "AntipatternSeveritySummaryTypeDef",
+    "AppUnitErrorTypeDef",
     "DatabaseConfigDetailTypeDef",
     "S3ObjectTypeDef",
     "SourceCodeRepositoryTypeDef",
+    "ApplicationComponentStatusSummaryTypeDef",
     "ApplicationComponentSummaryTypeDef",
+    "ServerStatusSummaryTypeDef",
     "ServerSummaryTypeDef",
     "StrategySummaryTypeDef",
+    "AssessmentTargetTypeDef",
     "AssociatedApplicationTypeDef",
     "AwsManagedResourcesTypeDef",
     "BusinessGoalsTypeDef",
-    "CollectorTypeDef",
+    "IPAddressBasedRemoteInfoTypeDef",
+    "PipelineInfoTypeDef",
+    "RemoteSourceCodeAnalysisServerInfoTypeDef",
+    "VcenterBasedRemoteInfoTypeDef",
+    "VersionControlInfoTypeDef",
     "DataCollectionDetailsTypeDef",
     "HeterogeneousTypeDef",
     "HomogeneousTypeDef",
@@ -92,16 +108,18 @@ __all__ = (
     "NetworkInfoTypeDef",
     "OSInfoTypeDef",
     "TransformationToolTypeDef",
+    "ServerErrorTypeDef",
     "SourceCodeTypeDef",
-    "StartAssessmentRequestRequestTypeDef",
     "StopAssessmentRequestRequestTypeDef",
     "StrategyOptionTypeDef",
     "AssessmentSummaryTypeDef",
+    "StartAssessmentRequestRequestTypeDef",
     "PrioritizeBusinessGoalsTypeDef",
+    "ConfigurationSummaryTypeDef",
     "DatabaseMigrationPreferenceTypeDef",
     "GetAssessmentResponseTypeDef",
     "GetImportFileTaskResponseTypeDef",
-    "ListCollectorsResponseTypeDef",
+    "GetLatestAssessmentIdResponseTypeDef",
     "StartAssessmentResponseTypeDef",
     "StartImportFileTaskResponseTypeDef",
     "StartRecommendationReportGenerationResponseTypeDef",
@@ -122,12 +140,14 @@ __all__ = (
     "UpdateApplicationComponentConfigRequestRequestTypeDef",
     "UpdateServerConfigRequestRequestTypeDef",
     "GetPortfolioSummaryResponseTypeDef",
+    "CollectorTypeDef",
     "DatabasePreferencesTypeDef",
     "ApplicationPreferencesTypeDef",
     "ApplicationComponentDetailTypeDef",
     "ApplicationComponentStrategyTypeDef",
     "ServerDetailTypeDef",
     "ServerStrategyTypeDef",
+    "ListCollectorsResponseTypeDef",
     "GetPortfolioPreferencesResponseTypeDef",
     "PutPortfolioPreferencesRequestRequestTypeDef",
     "GetApplicationComponentDetailsResponseTypeDef",
@@ -147,6 +167,14 @@ AntipatternSeveritySummaryTypeDef = TypedDict(
     total=False,
 )
 
+AppUnitErrorTypeDef = TypedDict(
+    "AppUnitErrorTypeDef",
+    {
+        "appUnitErrorCategory": AppUnitErrorCategoryType,
+    },
+    total=False,
+)
+
 DatabaseConfigDetailTypeDef = TypedDict(
     "DatabaseConfigDetailTypeDef",
     {
@@ -168,12 +196,22 @@ SourceCodeRepositoryTypeDef = TypedDict(
     "SourceCodeRepositoryTypeDef",
     {
         "branch": str,
+        "projectName": str,
         "repository": str,
         "versionControlType": str,
     },
     total=False,
 )
 
+ApplicationComponentStatusSummaryTypeDef = TypedDict(
+    "ApplicationComponentStatusSummaryTypeDef",
+    {
+        "count": int,
+        "srcCodeOrDbAnalysisStatus": SrcCodeOrDbAnalysisStatusType,
+    },
+    total=False,
+)
+
 ApplicationComponentSummaryTypeDef = TypedDict(
     "ApplicationComponentSummaryTypeDef",
     {
@@ -183,6 +221,15 @@ ApplicationComponentSummaryTypeDef = TypedDict(
     total=False,
 )
 
+ServerStatusSummaryTypeDef = TypedDict(
+    "ServerStatusSummaryTypeDef",
+    {
+        "count": int,
+        "runTimeAssessmentStatus": RunTimeAssessmentStatusType,
+    },
+    total=False,
+)
+
 ServerSummaryTypeDef = TypedDict(
     "ServerSummaryTypeDef",
     {
@@ -201,6 +248,15 @@ StrategySummaryTypeDef = TypedDict(
     total=False,
 )
 
+AssessmentTargetTypeDef = TypedDict(
+    "AssessmentTargetTypeDef",
+    {
+        "condition": ConditionType,
+        "name": str,
+        "values": List[str],
+    },
+)
+
 AssociatedApplicationTypeDef = TypedDict(
     "AssociatedApplicationTypeDef",
     {
@@ -228,16 +284,47 @@ BusinessGoalsTypeDef = TypedDict(
     total=False,
 )
 
-CollectorTypeDef = TypedDict(
-    "CollectorTypeDef",
+IPAddressBasedRemoteInfoTypeDef = TypedDict(
+    "IPAddressBasedRemoteInfoTypeDef",
     {
-        "collectorHealth": CollectorHealthType,
-        "collectorId": str,
-        "collectorVersion": str,
-        "hostName": str,
-        "ipAddress": str,
-        "lastActivityTimeStamp": str,
-        "registeredTimeStamp": str,
+        "authType": AuthTypeType,
+        "ipAddressConfigurationTimeStamp": str,
+        "osType": OSTypeType,
+    },
+    total=False,
+)
+
+PipelineInfoTypeDef = TypedDict(
+    "PipelineInfoTypeDef",
+    {
+        "pipelineConfigurationTimeStamp": str,
+        "pipelineType": Literal["AZURE_DEVOPS"],
+    },
+    total=False,
+)
+
+RemoteSourceCodeAnalysisServerInfoTypeDef = TypedDict(
+    "RemoteSourceCodeAnalysisServerInfoTypeDef",
+    {
+        "remoteSourceCodeAnalysisServerConfigurationTimestamp": str,
+    },
+    total=False,
+)
+
+VcenterBasedRemoteInfoTypeDef = TypedDict(
+    "VcenterBasedRemoteInfoTypeDef",
+    {
+        "osType": OSTypeType,
+        "vcenterConfigurationTimeStamp": str,
+    },
+    total=False,
+)
+
+VersionControlInfoTypeDef = TypedDict(
+    "VersionControlInfoTypeDef",
+    {
+        "versionControlConfigurationTimeStamp": str,
+        "versionControlType": VersionControlTypeType,
     },
     total=False,
 )
@@ -251,6 +338,7 @@ DataCollectionDetailsTypeDef = TypedDict(
         "servers": int,
         "startTime": datetime,
         "status": AssessmentStatusType,
+        "statusMessage": str,
         "success": int,
     },
     total=False,
@@ -379,7 +467,7 @@ GetServerStrategiesRequestRequestTypeDef = TypedDict(
 GroupTypeDef = TypedDict(
     "GroupTypeDef",
     {
-        "name": Literal["ExternalId"],
+        "name": GroupNameType,
         "value": str,
     },
     total=False,
@@ -464,21 +552,21 @@ TransformationToolTypeDef = TypedDict(
     total=False,
 )
 
-SourceCodeTypeDef = TypedDict(
-    "SourceCodeTypeDef",
+ServerErrorTypeDef = TypedDict(
+    "ServerErrorTypeDef",
     {
-        "location": str,
-        "sourceVersion": str,
-        "versionControl": VersionControlType,
+        "serverErrorCategory": ServerErrorCategoryType,
     },
     total=False,
 )
 
-StartAssessmentRequestRequestTypeDef = TypedDict(
-    "StartAssessmentRequestRequestTypeDef",
+SourceCodeTypeDef = TypedDict(
+    "SourceCodeTypeDef",
     {
-        "s3bucketForAnalysisData": str,
-        "s3bucketForReportData": str,
+        "location": str,
+        "projectName": str,
+        "sourceVersion": str,
+        "versionControl": VersionControlType,
     },
     total=False,
 )
@@ -509,14 +597,26 @@ AssessmentSummaryTypeDef = TypedDict(
         "antipatternReportStatusMessage": str,
         "lastAnalyzedTimestamp": datetime,
         "listAntipatternSeveritySummary": List[AntipatternSeveritySummaryTypeDef],
+        "listApplicationComponentStatusSummary": List[ApplicationComponentStatusSummaryTypeDef],
         "listApplicationComponentStrategySummary": List[StrategySummaryTypeDef],
         "listApplicationComponentSummary": List[ApplicationComponentSummaryTypeDef],
+        "listServerStatusSummary": List[ServerStatusSummaryTypeDef],
         "listServerStrategySummary": List[StrategySummaryTypeDef],
         "listServerSummary": List[ServerSummaryTypeDef],
     },
     total=False,
 )
 
+StartAssessmentRequestRequestTypeDef = TypedDict(
+    "StartAssessmentRequestRequestTypeDef",
+    {
+        "assessmentTargets": Sequence[AssessmentTargetTypeDef],
+        "s3bucketForAnalysisData": str,
+        "s3bucketForReportData": str,
+    },
+    total=False,
+)
+
 PrioritizeBusinessGoalsTypeDef = TypedDict(
     "PrioritizeBusinessGoalsTypeDef",
     {
@@ -525,6 +625,18 @@ PrioritizeBusinessGoalsTypeDef = TypedDict(
     total=False,
 )
 
+ConfigurationSummaryTypeDef = TypedDict(
+    "ConfigurationSummaryTypeDef",
+    {
+        "ipAddressBasedRemoteInfoList": List[IPAddressBasedRemoteInfoTypeDef],
+        "pipelineInfoList": List[PipelineInfoTypeDef],
+        "remoteSourceCodeAnalysisServerInfo": RemoteSourceCodeAnalysisServerInfoTypeDef,
+        "vcenterBasedRemoteInfoList": List[VcenterBasedRemoteInfoTypeDef],
+        "versionControlInfoList": List[VersionControlInfoTypeDef],
+    },
+    total=False,
+)
+
 DatabaseMigrationPreferenceTypeDef = TypedDict(
     "DatabaseMigrationPreferenceTypeDef",
     {
@@ -538,6 +650,7 @@ DatabaseMigrationPreferenceTypeDef = TypedDict(
 GetAssessmentResponseTypeDef = TypedDict(
     "GetAssessmentResponseTypeDef",
     {
+        "assessmentTargets": List[AssessmentTargetTypeDef],
         "dataCollectionDetails": DataCollectionDetailsTypeDef,
         "id": str,
         "ResponseMetadata": ResponseMetadataTypeDef,
@@ -562,11 +675,10 @@ GetImportFileTaskResponseTypeDef = TypedDict(
     },
 )
 
-ListCollectorsResponseTypeDef = TypedDict(
-    "ListCollectorsResponseTypeDef",
+GetLatestAssessmentIdResponseTypeDef = TypedDict(
+    "GetLatestAssessmentIdResponseTypeDef",
     {
-        "Collectors": List[CollectorTypeDef],
-        "nextToken": str,
+        "id": str,
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
@@ -776,6 +888,8 @@ _RequiredUpdateApplicationComponentConfigRequestRequestTypeDef = TypedDict(
 _OptionalUpdateApplicationComponentConfigRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateApplicationComponentConfigRequestRequestTypeDef",
     {
+        "appType": AppTypeType,
+        "configureOnly": bool,
         "inclusionStatus": InclusionStatusType,
         "secretsManagerKey": str,
         "sourceCodeList": Sequence[SourceCodeTypeDef],
@@ -822,6 +936,21 @@ GetPortfolioSummaryResponseTypeDef = TypedDict(
     },
 )
 
+CollectorTypeDef = TypedDict(
+    "CollectorTypeDef",
+    {
+        "collectorHealth": CollectorHealthType,
+        "collectorId": str,
+        "collectorVersion": str,
+        "configurationSummary": ConfigurationSummaryTypeDef,
+        "hostName": str,
+        "ipAddress": str,
+        "lastActivityTimeStamp": str,
+        "registeredTimeStamp": str,
+    },
+    total=False,
+)
+
 DatabasePreferencesTypeDef = TypedDict(
     "DatabasePreferencesTypeDef",
     {
@@ -847,6 +976,7 @@ ApplicationComponentDetailTypeDef = TypedDict(
         "antipatternReportStatus": AntipatternReportStatusType,
         "antipatternReportStatusMessage": str,
         "appType": AppTypeType,
+        "appUnitError": AppUnitErrorTypeDef,
         "associatedServerId": str,
         "databaseConfigDetail": DatabaseConfigDetailTypeDef,
         "id": str,
@@ -859,6 +989,8 @@ ApplicationComponentDetailTypeDef = TypedDict(
         "osVersion": str,
         "recommendationSet": RecommendationSetTypeDef,
         "resourceSubType": ResourceSubTypeType,
+        "runtimeStatus": RuntimeAnalysisStatusType,
+        "runtimeStatusMessage": str,
         "sourceCodeRepositories": List[SourceCodeRepositoryTypeDef],
         "statusMessage": str,
     },
@@ -888,6 +1020,7 @@ ServerDetailTypeDef = TypedDict(
         "listAntipatternSeveritySummary": List[AntipatternSeveritySummaryTypeDef],
         "name": str,
         "recommendationSet": RecommendationSetTypeDef,
+        "serverError": ServerErrorTypeDef,
         "serverType": str,
         "statusMessage": str,
         "systemInfo": SystemInfoTypeDef,
@@ -906,9 +1039,19 @@ ServerStrategyTypeDef = TypedDict(
     total=False,
 )
 
+ListCollectorsResponseTypeDef = TypedDict(
+    "ListCollectorsResponseTypeDef",
+    {
+        "Collectors": List[CollectorTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 GetPortfolioPreferencesResponseTypeDef = TypedDict(
     "GetPortfolioPreferencesResponseTypeDef",
     {
+        "applicationMode": ApplicationModeType,
         "applicationPreferences": ApplicationPreferencesTypeDef,
         "databasePreferences": DatabasePreferencesTypeDef,
         "prioritizeBusinessGoals": PrioritizeBusinessGoalsTypeDef,
@@ -919,6 +1062,7 @@ GetPortfolioPreferencesResponseTypeDef = TypedDict(
 PutPortfolioPreferencesRequestRequestTypeDef = TypedDict(
     "PutPortfolioPreferencesRequestRequestTypeDef",
     {
+        "applicationMode": ApplicationModeType,
         "applicationPreferences": ApplicationPreferencesTypeDef,
         "databasePreferences": DatabasePreferencesTypeDef,
         "prioritizeBusinessGoals": PrioritizeBusinessGoalsTypeDef,
